@@ -13,7 +13,7 @@ from __future__ import absolute_import, division, unicode_literals
 
 from mo_threads import Queue, THREAD_STOP, Thread, Till
 
-from mo_logs import Except, Log
+from mo_logs import Except, logger
 from mo_logs.log_usingNothing import StructuredLogger
 
 DEBUG = False
@@ -52,7 +52,7 @@ class StructuredLogger_usingThread(StructuredLogger):
             self.queue.add(THREAD_STOP)  # BE PATIENT, LET REST OF MESSAGE BE SENT
             self.thread.join()
         except Exception as e:
-            Log.note("problem in threaded logger" + str(e))
+            logger.info("problem in threaded logger" + str(e))
 
 
 def worker(logger, queue, period, please_stop):
